@@ -199,63 +199,6 @@ terminal_app_init_debug (void)
 
 /* Helper functions */
 
-static void
-maybe_migrate_settings (TerminalApp *app)
-{
-#ifdef ENABLE_MIGRATION
-  const char * const argv[] = { 
-    TERM_LIBEXECDIR "/gnome-terminal-migration",
-#ifdef ENABLE_DEBUG
-    "--verbose", 
-#endif
-    NULL 
-  };
-  int status;
-  gs_free_error GError *error = NULL;
-#endif /* ENABLE_MIGRATION */
-  guint version;
-
-  version = g_settings_get_uint (terminal_app_get_global_settings (app), TERMINAL_SETTING_SCHEMA_VERSION);
-  if (version >= TERMINAL_SCHEMA_VERSION) {
-     _terminal_debug_print (TERMINAL_DEBUG_SERVER | TERMINAL_DEBUG_PROFILE,
-                            "Schema version is %u, already migrated.\n", version);
-    return;
-  }
-
-#ifdef ENABLE_MIGRATION
-  /* Only do migration if the settings backend is dconf */
-  GType type = G_OBJECT_TYPE (g_settings_backend_get_default ());
-  if (!g_type_is_a (type, g_type_from_name ("DConfSettingsBackend"))) {
-    _terminal_debug_print (TERMINAL_DEBUG_SERVER | TERMINAL_DEBUG_PROFILE,
-                           "Not migration settings to %s\n", g_type_name (type));
-    goto done;
-  }
-
-  if (!g_spawn_sync (NULL /* our home directory */,
-                     (char **) argv,
-                     NULL /* envv */,
-                     0,
-                     NULL, NULL,
-                     NULL, NULL,
-                     &status,
-                     &error)) {
-    g_printerr ("Failed to migrate settings: %s\n", error->message);
-    return;
-  }
-
-  if (WIFEXITED (status)) {
-    if (WEXITSTATUS (status) != 0)
-      g_printerr ("Profile migrator exited with status %d\n", WEXITSTATUS (status));
-  } else {
-    g_printerr ("Profile migrator exited abnormally.\n");
-  }
-done:
-#endif /* ENABLE_MIGRATION */
-  g_settings_set_uint (terminal_app_get_global_settings (app),
-                       TERMINAL_SETTING_SCHEMA_VERSION,
-                       TERMINAL_SCHEMA_VERSION);
-}
-
 static gboolean
 load_css_from_resource (GApplication *application,
                         GtkCssProvider *provider,
@@ -429,7 +372,7 @@ menu_append_numbered (GMenu *menu,
                       const char *label,
                       int num,
                       const char *action_name,
-                      GVariant *target)
+                      GVariant *target /* floating, consumed */)
 {
   gs_free_gstring GString *str;
   gs_unref_object GMenuItem *item;
@@ -477,7 +420,7 @@ append_new_terminal_item (GMenu *section,
     g_menu_item_set_link (item, G_MENU_LINK_SUBMENU, G_MENU_MODEL (submenu));
   } else {
     g_menu_item_set_action_and_target (item, "win.new-terminal",
-                                       "(ss)", target, "default");
+                                       "(ss)", target, "current");
   }
   g_menu_append_item (section, item);
 }
@@ -499,12 +442,11 @@ static GMenu *
 set_profile_submenu_new (ProfileData *data,
                          guint n_profiles)
 {
-  GMenu *menu = g_menu_new ();
-
   /* No submenu if there's only one profile */
   if (n_profiles <= 1)
     return NULL;
 
+  GMenu *menu = g_menu_new ();
   for (guint i = 0; i < n_profiles; i++) {
     menu_append_numbered (menu, data[i].label, i + 1,
                           "win.profile",
@@ -781,9 +723,6 @@ terminal_app_init (TerminalApp *app)
   if (!gdk_display_supports_selection_notification (display))
     g_printerr ("Display does not support owner-change; copy/paste will be broken!\n");
 
-  /* Check if we need to migrate from gconf to dconf */
-  maybe_migrate_settings (app);
-
   /* Get the profiles */
   app->profiles_list = terminal_profiles_list_new ();
 
